==> izon-db-4.2.3.3-333463.zip: src/IZON/DB/Utils/PropertyDescriptions/CharDescription.php <==
<?php

namespace IZON\DB\Utils\PropertyDescriptions;

use \PDO;
use \Exception;

use IZON\DB\Utils\ClassDescription;

/**
 * Popis data
 */
class CharDescription extends AbstractPropertyDescription {
    
    protected $maxLength = PHP_INT_MAX; 
            
    function __construct(ClassDescription $classDesctiption,
                            $propertyName, $columnName, $columnReturnName, $notNull, array $parameters) {
        parent::__construct($classDesctiption, $propertyName, $columnName, $columnReturnName, $notNull, $parameters);
        
        $this->dbDataType = "varchar";
        $this->pdoDataType = PDO::PARAM_STR;
        $this->ansiDataType = AbstractPropertyDescription::ANSI_DATA_TYPE_CHAR_VARYING;
    }

    public function parse($value, $object) {
        if(  $value === NULL ) {
            if( $this->getNotNull() ) {
                throw new Exception("". $this->getPropertyName() ." nesmi byt null");
            }
            return NULL;
        }
        
        if( mb_strlen($value) > $this->maxLength ) {
            throw new Exception("". $this->getPropertyName() ." nesmi byt delsi nez ". $this->maxLength);
        }
        
        $date = $value;
        return $date;
    }

    public function serialize($value, $object) {
        if(  $value === NULL ) {
            if( $this->getNotNull() ) {
                throw new Exception("". $this->getPropertyName() ." nesmi byt null");
            }
            return NULL;
        }
        
        if( mb_strlen($value) > $this->maxLength ) {
            throw new Exception("". $this->getPropertyName() ." nesmi byt delsi nez ". $this->maxLength);
        }
        
        return $value;
    }

    function getPdoDataType($value) {
        if( $value === NULL )
            return PDO::PARAM_NULL;
        return $this->pdoDataType;
    }
    
    function getMaxLength() {
        return $this->maxLength;
    }

    function setMaxLength($maxLength) {
        $this->maxLength = $maxLength;
    }
}

==> izon-db-4.3.8-a30297.zip: src/IZON/DB/Utils/PropertyDescriptions/CharDescription.php <==
<?php

namespace IZON\DB\Utils\PropertyDescriptions;

use \PDO;
use \Exception;

use IZON\DB\Utils\ClassDescription;

/**
 * Popis data
 */
class CharDescription extends AbstractPropertyDescription {
    
    protected $maxLength = PHP_INT_MAX; 
            
    function __construct(ClassDescription $classDescription,
                            $propertyName, $columnName, $columnReturnName, $notNull, array $parameters) {
        parent::__construct($classDescription, $propertyName, $columnName, $columnReturnName, $notNull, $parameters);
        
        $this->dbDataType = "varchar";
        $this->pdoDataType = PDO::PARAM_STR;
        $this->ansiDataType = AbstractPropertyDescription::ANSI_DATA_TYPE_CHAR_VARYING;
    }

    public function parse($value, $object) {
        if(  $value === NULL ) {
            if( $this->getNotNull() ) {
                throw new Exception("". $this->getPropertyName() ." nesmi byt null");
            }
            return NULL;
        }
        
        if( mb_strlen($value) > $this->maxLength ) {
            throw new Exception("". $this->getPropertyName() ." nesmi byt delsi nez ". $this->maxLength);
        }
        
        $date = $value;
        return $date;
    }

    public function serialize($value, $object) {
        if(  $value === NULL ) {
            if( $this->getNotNull() ) {
                throw new Exception("". $this->getPropertyName() ." nesmi byt null");
            }
            return NULL;
        }
        
        if( mb_strlen($value) > $this->maxLength ) {
            throw new Exception("". $this->getPropertyName() ." nesmi byt delsi nez ". $this->maxLength);
        }
        
        return $value;
    }

    function getPdoDataType($value) {
        if( $value === NULL )
            return PDO::PARAM_NULL;
        return $this->pdoDataType;
    }
    
    function getMaxLength() {
        return $this->maxLength;
    }

    function setMaxLength($maxLength) {
        $this->maxLength = $maxLength;
    }
}
